<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based photo gallery                                    |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2011 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+

$lang['%d association'] = '%d associação';
$lang['%d associations'] = '%d associações';
$lang['%d album including'] = '%d álbum incluído ';
$lang['%d albums including'] = '%d álbums incluídos ';
$lang['%d physical'] = '%d físico';
$lang['%d physical'] = '%d físicos';
$lang[' and %d virtual'] = ' e %d virtual';
$lang[' and %d virtual'] = ' e %d virtuais';
$lang['%d album moved'] = '%d álbum movido';
$lang['%d albums moved'] = '%d álbums movidos';
$lang['%d group'] = '%d grupo';
$lang['%d groups'] = '%d grupos';
$lang['%d member'] = '%d membro';
$lang['%d members'] = '%d membros';
$lang['%d tag'] = '%d etiqueta';
$lang['%d tags'] = '%d etiquetas';
$lang['%d user comment rejected'] = '%d comentário de utilizador rejeitado';
$lang['%d user comments rejected'] = '%d comentários de utilizador rejeitados';
$lang['%d user comment validated'] = '%d comentário de utilizador aprovado';
$lang['%d user comments validated'] = '%d comentários de utilizador aprovados';
$lang['%d user deleted'] = '%d utilizador apagado';
$lang['%d users deleted'] = '%d utilizadores apagados';
$lang['%d user'] = '%d utilizador';
$lang['%d users'] = '%d utilizadores';
$lang['%d waiting for validation'] = '%d a aguardar aprovação';
$lang['Actions'] = 'Acções';
$lang['Activate'] = 'Activar';
$lang['Add/delete a permalink'] = 'Adicionar/apagar um link';
$lang['Add a tag'] = 'Adicionar uma etiqueta';
$lang['Add a user'] = 'Adicionar um utilizador';
$lang['Add group'] = 'Adicionar um grupo';
$lang['Add'] = 'Adicionar';
$lang['Allow user registration'] = 'Permitir o registo de utilizadores';
$lang['Apply to sub-albums'] = 'Aplicar aos sub-álbums';
$lang['Associated'] = 'Associados(as)';
$lang['Batch management'] = 'Gestão de ficheiros em lote';
$lang['Caddie management'] = 'Gestão do carrinho';
$lang['Caddie'] = 'Carrinho';
$lang['Albums authorized thanks to group associations'] = 'Álbums autorizados graças a associações de grupo';
$lang['Album manual order was saved'] = 'A ordem manual das álbums foi salva';
$lang['Check for upgrade failed for unknown reasons.'] = 'A procura de actualizações falhou por razões desconhecidas.';
$lang['Check for upgrade'] = 'procurar por actualizações';
$lang['Comments for all'] = 'Comentários para todos';
$lang['Current name'] = 'Nome actual';
$lang['Database'] = 'Base de dados';
$lang['Deactivate'] = 'Desactivar';
$lang['Delete Representant'] = 'Apagar capa de álbum';
$lang['Delete selected tags'] = 'Apagar etiquetas selecionadas';
$lang['Delete selected users'] = 'Apagar utilizadores selecionados';
$lang['Deletions'] = 'Items apagados';
$lang['Deny selected groups'] = 'Negar os grupos selecionados';
$lang['Deny selected users'] = 'Negar utilizadores selecionados';
$lang['Description'] = 'Descrição';
$lang['Display options'] = 'Mostrar opções';
$lang['Dissociated'] = 'Desassociados';
$lang['Does not represent'] = 'Não representa';
$lang['Edit selected tags'] = 'Editar etiquetas selecionadas';
$lang['Edit tags'] = 'Editar etiquetas';
$lang['Email admins when a new user registers'] = 'Notificar os administradores quando um novo utilizador se registar';
$lang['Email admins when a valid comment is entered'] = 'Notificar os administradores quando um comentário aprovado for incluído';
$lang['Email admins when a comment requires validation'] = 'Notificar os administradores quando um comentário necessitar de aprovação';
$lang['Environment'] = 'Ambiente';
$lang['Form'] = 'Formulário';
$lang['Gallery title'] = 'Título da galeria';
$lang['Grant selected groups'] = 'Permitir os grupos selecionados';
$lang['Grant selected users'] = 'Permitir os utilizadores selecionados';
$lang['Group name'] = 'Nome do grupo';
$lang['Groups'] = 'Grupos';
$lang['Guests'] = 'Visitantes';
$lang['History'] = 'Histórico';
$lang['Informations'] = 'Informações';
$lang['Install'] = 'Instalar';
$lang['Link all album photos to a new album'] = 'Vincular todos os items do álbum a um novo álbum';
$lang['Link all album photos to some existing albums'] = 'Vincular todos os items do álbum a um álbum já existente';
$lang['Linked albums'] = 'Álbums vinculados';
$lang['Lock gallery'] = 'Trancar a  galeria';
$lang['Maintenance'] = 'Manutenção';
$lang['Edit album permissions'] = 'Gerir permissões do álbum';
$lang['Manage permissions for group "%s"'] = 'Gerir permissões do grupo "%s"';
$lang['Manage permissions for user "%s"'] = 'Gerir permissões do utilizador "%s"';
$lang['Manage tags'] = 'Gerir etiquetas';
$lang['Members'] = 'Membros';
$lang['Metadata synchronized from file'] = 'Metadados sincronizados do ficheiro';
$lang['Move albums'] = 'Mover álbums';
$lang['Move'] = 'Mover';
$lang['Name'] = 'Nome';
$lang['New name'] = 'Novo nome';
$lang['New parent album'] = 'Novo álbum pai';
$lang['New tag'] = 'Etiqueta nova';
$lang['Number of comments per page'] = 'Número de comentários por página';
$lang['Number of rates'] = 'Número de votos';
$lang['Number of thumbnails to create'] = 'Número de miniaturas a serem criadas';
$lang['Only private albums are listed'] = 'Apenas os álbums privados estão listados';
$lang['Operating system'] = 'Sistema operativo';
$lang['Options'] = 'Opções';
$lang['Other private albums'] = 'Outros álbums privados';
$lang['Page banner'] = 'Cabeçalho de página';
$lang['Parent album'] = 'Álbum pai';
$lang['Path'] = 'Caminho';
$lang['Permalink'] = 'Ligação Permanente';
$lang['Permalink %s has been previously used by album %s. Delete from the permalink history first'] = 'A Ligação Permanente %s já está a ser usada pelo álbum %s. Apague-o do histórico de ligações permanentes primeiro';
$lang['The permalink name must be composed of a-z, A-Z, 0-9, "-", "_" or "/". It must not be numeric or start with number followed by "-"'] = 'A Ligação Permanente deve ser composta de a-z, A-Z, 0-9, "-", "_" ou "/". Não deve ser numérica ou começar com número seguido de "-"';
$lang['Permalink %s is already used by album %s'] = 'A Ligação Permanente %s já está a ser usada pelo álbum %s';
$lang['Permalink history'] = 'Histórico de ligações permanentes';
$lang['Permalinks'] = 'Ligações Permanentes';
$lang['Permission denied'] = 'Permissão negada';
$lang['Permission granted thanks to a group'] = 'Permissão garantida graças ao grupo';
$lang['Permission granted'] = 'Permissão garantida';
$lang['Photo informations updated'] = 'Informações da foto actualizadas';
$lang['Plugins'] = 'Extensões';
$lang['Position'] = 'Posição';
$lang['Preferences'] = 'Preferências';
$lang['Properties'] = 'Propriedades';
$lang['Random photo'] = 'Foto aleatória';
$lang['Rate date'] = 'Data da classificação';
$lang['Rating by guests'] = 'Classificado(a) pelos visitantes';
$lang['Rating'] = 'Classificação';
$lang['Reject'] = 'Rejeitar';
$lang['Representant'] = 'Capa de Álbum';
$lang['Representation of albums'] = 'Capas dos álbums';
$lang['Representative'] = 'Capa';
$lang['Represents'] = 'É capa';
$lang['Save order'] = 'Salvar ordem';
$lang['Save to permalink history'] = 'Salvar no histórico de ligações permanentes';
$lang['Select at least one album'] = 'Seleccionar pelo menos um álbum';
$lang['Select at least one photo'] = 'Seleccionar pelo menos uma foto';
$lang['Select at least one user'] = 'Seleccionar pelo menos um utilizador';
$lang['Show info'] = 'Mostrar informação';
$lang['Site manager'] = 'Gerir a galeria';
$lang['Status'] = 'Estatuto';
$lang['Statistics'] = 'Estatísticas';
$lang['Storage album'] = 'Armazenagem de álbum';
$lang['Sum of rates'] = 'Soma das classificações';
$lang['Tag "%s" already exists'] = 'A etiqueta "%s" já existe';
$lang['Tag "%s" was added'] = 'A etiqueta "%s" foi adicionada';
$lang['Tag selection'] = 'Seleção de etiqueta';
$lang['The %d following tags were deleted'] = 'As %d etiquetas seguintes foram apagadas';
$lang['Unable to check for upgrade.'] = 'Não foi possível procurar actualizações.';
$lang['Uninstall'] = 'Desinstalar';
$lang['Use the default photo sort order (defined in the configuration file)']='Usar a ordem de exibição padrão (definida no ficheiro de configuração)';
$lang['User comments validation'] = 'Aprovação dos comentários de utilizador';
$lang['Users'] = 'Utilizadores';
$lang['Validate'] = 'Aprovar';
$lang['Validation'] = 'Aprovação';
$lang['Version'] = 'Versão';
$lang['Virtual albums to move'] = 'Álbums virtuais a serem movidos';
$lang['Virtual album name'] = 'Nome do álbum virtual';
$lang['Webmaster cannot be deleted'] = 'O Utilizador Webmaster não pode ser apagado';
$lang['You are running on development sources, no check possible.'] = 'Você está a usar código fonte de desenvolvimento, nenhuma verificação é possível.';
$lang['You cannot delete your account'] = "Não pode apagar a sua conta";
$lang['You cannot move an album in its own sub album'] = 'Não pode mover um álbum para um dos seus sub-álbums.';
$lang['You need to confirm deletion'] = 'Precisa confirmar a remoção';
$lang['add tags'] = 'adicionar etiquetas';
$lang['Associate to album'] = 'Associar ao álbum';
$lang['associate to group'] = 'Associar ao grupo';
$lang['Authorized'] = 'Autorizado';
$lang['Add a virtual album'] = 'Adicionar um álbum virtual';
$lang['Authorize users to add comments on selected albums'] = 'Autorizar os utilizadores a adicionar comentários nos álbums seleccionados';
$lang['The name of an album must not be empty'] = 'O nome de um álbum não deverá ser vazio';
$lang['Lock albums'] = 'Trancar álbums';
$lang['Private'] = 'Álbums privados';
$lang['Public'] = 'Álbums públicas';
$lang['Find a new representant by random'] = 'Encontrar uma nova capa aleatoriamente';
$lang['Public / Private'] = 'Público / Privado';
$lang['Manage authorizations for selected albums'] = 'Gerir as autorizações para os álbums seleccionadas';
$lang['Virtual album added'] = 'Álbum virtual adicionado';
$lang['Virtual album deleted'] = 'Álbum virtual apagado';
$lang['Access type'] = 'Acesso';
$lang['Comments'] = 'Comentários';
$lang['Information data registered in database'] = 'Dados de informação registados na base de dados';
$lang['Default display'] = 'Exibição padrão';
$lang['The gallery URL is not valid.'] = 'O URL (endereço) da galeria não é valido.';
$lang['Main'] = 'Principal';
$lang['The number of comments a page must be between 5 and 50 included.'] = 'O número de comentários por página deve ser entre 5 e 50 .';
$lang['Configuration'] = 'Configuração';
$lang['confirm'] = 'Confirmar';
$lang['Date'] = 'Data';
$lang['delete album'] = 'Apagar álbum';
$lang['Dissociate from album'] = 'Desassociar do álbum';
$lang['dissociate from group'] = 'Desassociar do grupo';
$lang['edit album permissions'] = 'editar as permissões da álbum';
$lang['Album updated successfully'] = 'As informações do álbum foram actualizadas com sucesso.';
$lang['photos per page'] = 'Fotos por página';
$lang['High definition enabled'] = 'Alta definição activada';
$lang['File'] = 'Ficheiro';
$lang['Filesize'] = 'Tamanho do ficheiro';
$lang['first photo added on %s'] = 'primeira foto adicionada em %s';
$lang['Forbidden'] = 'Proibido';
$lang['global mode'] = 'modo global';
$lang['group "%s" added'] = 'grupo "%s" adicionado';
$lang['group "%s" deleted'] = 'grupo "%s" apagado';
$lang['group "%s" updated'] = 'grupo "%s" actualizado';
$lang['group'] = 'grupo';
$lang['The name of a group must not contain " or \' or be empty.'] = 'O nome de um grupo não deve conter " ou \' ou ser vazio.';
$lang['This name is already used by another group.'] = 'Este nome já é usado por outro grupo.';
$lang['High definition'] = 'Alta definição';
$lang['jump to album'] = 'ir para álbum';
$lang['jump to photo'] = 'ir para foto';
$lang['leave'] = 'Manter';
$lang['Lock'] = 'Trancar';
$lang['Locked'] = 'Trancado';
$lang['manage album photos'] = 'Gerir as fotos do álbum';
$lang['manage sub-albums'] = 'Gerir sub-álbums';
$lang['Manage'] = 'Gerir';
$lang['maximum height'] = 'Altura máxima';
$lang['maximum width'] = 'Largura máxima';
$lang['Execution time is out, treatment must be continue [Estimated time: %d second].'] = 'O tempo de execução acabou, tratamento deve ser contínuo [Tempo estimado: %d segundo].';
$lang['Execution time is out, treatment must be continue [Estimated time: %d seconds].'] = 'O tempo de execução acabou, tratamento deve ser contínuo [Tempo estimado: %d segundos].';
$lang['Prepared time for list of users to send mail is limited. Others users are not listed.'] = 'O tempo disponível para a criação da lista de utilizadores para enviar email é limitado. Outros utilizadores não estão listados.';
$lang['Time to send mail is limited. Others mails are skipped.'] = 'O tempo para enviar email é limitado. Outros emails serão desconsiderados.';
$lang['To send ?'] = 'Enviar ?';
$lang['Last send'] = 'Enviado pela última vez';
$lang['email'] = 'Email';
$lang['User'] = 'Utilizador';
$lang['Complementary mail content'] = 'Conteúdo complementar da correspondência';
$lang['See you soon,'] = 'Até breve,';
$lang['Go to'] = 'Ir à(ao) ';
$lang['Hello'] = 'Olá ';
$lang['New photos were added'] = 'Novas fotos foram adicionadas ';
$lang['on'] = ' em ';
$lang['between'] = 'entre ';
$lang['and'] = ' e ';
$lang['The webmaster has subscribed you to receiving notifications by mail.'] = 'O webmaster subscreveu-o para receber notificações por email.';
$lang['You have subscribed to receiving notifications by mail.'] = 'Você subscreveu as notificações por email.';
$lang['To subscribe'] = 'Subscrever';
$lang['If you encounter problems or have any question, please send a message to'] = 'Se encontrar problemas ou tiver qualquer pergunta, por favor envie uma mensagem para ';
$lang['[NBM] Problems or questions'] = '[Notificação] Problemas ou perguntas';
$lang['The webmaster has unsubscribed you from receiving notifications by mail.'] = 'O webmaster retirou-o da lista de subscrição para receber notificações por email.';
$lang['You have unsubscribed from receiving notifications by mail.'] = 'Você saiu da lista de subscrição para receber notificações por email.';
$lang[', click on'] = ', clique em ';
$lang['To unsubscribe'] = 'Cancelar subscrição';
$lang['With blank value, gallery title will be used'] = 'Com valor em branco, o título da galeria será usado';
$lang['Notification'] = 'Notificação';
$lang['Error when sending email to %s [%s].'] = 'Erro ao enviar email para %s [%s].';
$lang['Mail sent to %s [%s].'] = 'Email enviado para %s [%s].';
$lang['%d mail was sent.'] = '%d email foi enviado.';
$lang['%d mails were sent.'] = '%d emails foram enviados.';
$lang['%d mail was not sent.'] = '%d email não foi enviado.';
$lang['%d mails were not sent.'] = '%d emails não foram enviados.';
$lang['No mail to send.'] = 'Nenhum email para enviar.';
$lang['There is no available subscribers to mail.'] = 'Não existem subscritores para enviar email.';
$lang['Subscribers could be listed (available) only if there is new elements to notify.'] = 'Subscritores apenas poderão ser listados quando existirem novos items para notificar.';
$lang['Anyway only webmasters can see this tab and never administrators.'] = 'Em todo caso, apenas webmasters podem ver este separador e nunca administradores.';
$lang['No user to send notifications by mail.'] = 'Nenhum utilizador para enviar notificações por email.';
$lang['New photos added'] = 'Novas fotos adicionados';
$lang['Subscribe to notification by mail'] = 'Subscrever as notificações por email';
$lang['Unsubscribe from notification by mail'] = 'Cancelar a subscrição das notificações por email';
$lang['Parameter'] = 'Parâmetro';
$lang['Continue processing treatment'] = 'Continuar a processar tratamento';
$lang['Complementary mail content'] = 'Conteúdo complementar da correspondência';
$lang['Add detailed content'] = 'Adicionar conteúdo detalhado';
$lang['Send mail as'] = 'Enviar email como';
$lang['Send mail to users'] = 'Enviar email aos utilizadores';
$lang['Send'] = 'Enviar';
$lang['Options'] = 'Opções';
$lang['Subscribed'] = 'Subscritos';
$lang['Subscribe'] = 'Subscrever';
$lang['Parameters'] = 'Parâmetros';
$lang['Select recipients'] = 'Selecionar os destinatários';
$lang['Subscribe/unsubscribe users'] = 'Assinar/Cancelar Subscrição dos utilizadores';
$lang['Unsubscribed'] = 'Subscrição Cancelada';
$lang['%d parameter was updated.'] = '%d parâmetro foi actualizado.';
$lang['%d parameters were updated.'] = '%d parâmetros foram actualizados.';
$lang['%d user was not updated.'] = '%d utilizador não foi actualizado.';
$lang['%d users were not updated.'] = '%d utilizadores não foram actualizados.';
$lang['User %s [%s] was removed from the subscription list.'] = 'Utilizador %s [%s] foi removido da lista de subscritores.';
$lang['User %s [%s] was added to the subscription list.'] = 'Utilizador %s [%s] foi adicionado na lista de subscritores.';
$lang['%d user was updated.'] = '%d utilizador foi actualizado.';
$lang['%d users were updated.'] = '%d utilizadores foram actualizados.';
$lang['User %s [%s] was not removed from the subscription list.'] = 'Utilizador %s [%s] não foi removido da lista de subscritores.';
$lang['User %s [%s] was not added to the subscription list.'] = 'Utilizador %s [%s] não foi adicionado na lista de subscritores.';
$lang['User %s [%s] added.'] = 'Utilizador %s [%s] adicionado.';
$lang['Warning: subscribing or unsubscribing will send mails to users'] = 'Aviso: activando ou cancelando a subscrição enviará correspondência aos utilizadores';
$lang['Send mail on HTML format'] = 'Enviar a correspondência no formato HTML';
$lang['Include display of recent photos grouped by dates'] = 'Incluír a exibição do grupo das fotos recentes por datas';
$lang['Available only with HTML format'] = 'Disponível apenas com o formato HTML';
$lang['no write access'] = 'Sem acesso de escrita';
$lang['Permissions'] = 'Permissões';
$lang['private'] = 'Privado';
$lang['public'] = 'Público';
$lang['Purge never used notification feeds'] = 'Limpar as notificações que nunca foram enviadas';
$lang['Purge sessions'] = 'Limpar as sessões';
$lang['randomly represented'] = 'aleatoriamente representado';
$lang['registration date'] = 'data de registo';
$lang['clean'] = 'limpar';
$lang['remove remote listing.xml file'] = 'remover o ficheiro remoto listing.xml';
$lang['generate listing'] = 'gerar lista';
$lang['generate file listing.xml on remote site'] = 'gerar ficheiro listing.xml no site remoto';
$lang['Create this site'] = 'Criar este site';
$lang['A local listing.xml file has been found for'] = 'Um ficheiro local listing.xml foi encontrado por ';
$lang['read local listing.xml and update'] = 'ler o ficheiro local listing.xml e actualizar';
$lang['test'] = 'testar';
$lang['test this remote site'] = 'testar este site remoto';
$lang['remove tags'] = 'remover etiquetas';
$lang['Repair and optimize database'] = 'Reparar e optimizar a base de dados';
$lang['selection'] = 'selecção';
$lang['set to'] = 'definir para';
$lang['singly represented'] = 'unicamente representado';
$lang['This site already exists'] = 'Este site já existe';
$lang['Create a new site : (give its URL to create_listing_file.php)'] = 'Criar um site novo : (dê seu URL para create_listing_file.php)';
$lang['created'] = 'criado';
$lang['delete'] = 'apagar';
$lang['delete this site and all its attached elements'] = 'apagar este site e todos os elementos associados a ele';
$lang['deleted'] = 'apagado';
$lang['an error happened'] = 'aconteceu um erro';
$lang['file create_listing_file.php on remote site was not found'] = 'o ficheiro create_listing_file.php no site remoto não foi encontrado';
$lang['Local'] = 'Local';
$lang['Remote'] = 'Remoto';
$lang['synchronize'] = 'sincronizar';
$lang['update the database from files'] = 'usar os ficheiros para atualizar a base de dados';
$lang['status'] = 'estado';
$lang['Directory'] = 'Pasta';
$lang['sub-albums'] = 'sub-álbums';
$lang['synchronize metadata'] = 'sincronizar meta-dados';
$lang['target'] = 'alvo';
$lang['Thumbnail'] = 'Miniatura';
$lang['title'] = 'título';
$lang['Album list management'] = 'Gerir lista álbums';
$lang['Piwigo configuration'] = 'Configuração Piwigo';
$lang['Edit album'] = 'Editar um álbum';
$lang['Group management'] = 'Gestão de grupos';
$lang['User list'] = 'Lista de utilizadores';
$lang['Edit photo information'] = 'Modificar informações sobre uma foto';
$lang['Thumbnail creation'] = 'Criação de miniatura';
$lang['Database synchronization with files'] = 'Sincronização da base de dados com os ficheiros';
$lang['all'] = 'tudo';
$lang['photos without thumbnail (jpeg and png only)'] = 'fotos sem miniatura (jpeg e png apenas)';
$lang['height must be a number superior to'] = 'altura deve ser um número superior a';
$lang['width must be a number superior to'] = 'largura deve ser um número superior a';
$lang['for the file format'] = 'para o formato de ficheiro';
$lang['No missing thumbnail'] = 'Nenhuma miniatura em falta';
$lang['Photo unreachable or no support'] = 'Foto não alcançável ou sem suporte';
$lang['GD version'] = 'versão GD';
$lang['Miniaturization parameters'] = 'Parâmetros da miniaturização';
$lang['generated in'] = 'gerado em';
$lang['Results of miniaturization'] = 'Resultados da miniaturização';
$lang['General statistics'] = 'Estatísticas gerais';
$lang['max time'] = 'tempo máximo';
$lang['average time'] = 'tempo médio';
$lang['min time'] = 'tempo mínimo';
$lang['number of miniaturized photos'] = 'número de fotos miniaturizadas';
$lang['total time'] = 'tempo total';
$lang['for this file format'] = 'para este formato de ficheiro';
$lang['unit mode'] = 'modo unitário';
$lang['Unlocked'] = 'Destrancado';
$lang['unset'] = 'não definido';
$lang['Update albums informations'] = 'Atualizar as informações dos álbums';
$lang['Update photos information'] = 'Atualizar as informações das fotos';
$lang['Synchronize'] = 'Sincronizar';
$lang['reduce to single existing albums'] = 'reduzir os álbums existentes em apenas um';
$lang['Choose an option'] = 'Escolher uma opção';
$lang['display maximum informations (added albums and photos, deleted albums and photos)'] = 'exibir o máximo de informações (álbums e fotos adicionados, álbums e fotos apagados)';
$lang['Piwigo version differs on the remote site'] = 'Versão Piwigo difere do site remoto';
$lang['Version of create_listing_file.php on the remote site and Piwigo must be the same'] = 'A versão de create_listing_file.php no site remoto e do Piwigo devem ser a mesma';
$lang['listing.xml file was not found'] = 'o ficheiro listing.xml não foi encontrado';
$lang['listing.xml file was not found on the remote site. This file is generated by choosing the "generate listing" command in the Site manager'] = 'O ficheiro listing.xml não foi encontrado no site remoto. Este ficheiro é criado ao escolher o comando "generate listing" no Gestor de Galeria';
$lang['Error list'] = 'Lista de erros';
$lang['Errors caption'] = 'Captura de erros';
$lang['Detailed informations'] = 'Informações detalhadas';
$lang['File/directory read error'] = 'Erro de leitura em ficheiro/pasta';
$lang['The file or directory cannot be accessed (either it does not exist or the access is denied)'] = 'O ficheiro ou pasta não pode ser acedido (ou ele não existe ou o acesso foi negado)';
$lang['a picture filetype requires a thumbnail. The thumbnail must be present in the sub-directory "thumbnail" of the album directory. The thumbnail filename must start with the configured thumbnail prefix and the extension must be among the following list :'] = 'Um tipo de ficheiro de imagem requer uma miniatura. A miniatura deve estar presente no sub-diretório "thumbnail" da pasta do álbum. O nome de ficheiro da miniatura deve começar com o prefixo pré-configurado para a miniatura e a extensão deve estar entre a seguinte lista :';
$lang['missing thumbnail'] = 'miniatura em falta';
$lang['albums deleted in the database'] = 'álbums apagados da base de dados';
$lang['photos deleted from the database'] = 'fotos apagadas da base de dados';
$lang['photos candidates for metadata synchronization'] = 'fotos candidatas para a sincronização de meta-dados';
$lang['photos informations synchronized with files metadata'] = 'as informações das fotos foram sincronizados com os meta-dados dos ficheiros';
$lang['errors during synchronization'] = 'erros durante a sincronização';
$lang['albums added in the database'] = 'álbums adicionados à base de dados';
$lang['photos added in the database'] = 'fotos adicionadas à base de dados';
$lang['photos updated in the database'] = 'fotos actualizadas na base de dados';
$lang['Search for new images in the directories'] = 'Pesquisar novas fotos nas pastas';
$lang['added'] = 'adicionado(a)';
$lang['deleted'] = 'apagado(a)';
$lang['Metadata synchronization results'] = 'Resultados da sincronização de meta-dados';
$lang['only perform a simulation (no change in database will be made)'] = 'apenas executa uma simulação (não será feita alteração alguma na base de dados)';
$lang['[Simulation]'] = '[Simulação]';
$lang['directories + files'] = 'pastas + ficheiros';
$lang['only directories'] = 'apenas pastas';
$lang['synchronize files structure with database'] = 'sincronizar a estrutura dos ficheiros com a base de dados';
$lang['synchronize files metadata with database photos informations'] = 'sincronizar os meta-dados dos ficheiros com as informações das fotos na base de dados';
$lang['even already synchronized photos'] = 'fotos já sincronizadas';
$lang['Used metadata'] = 'Metadados usados';
$lang['The name of directories and files must be composed of letters, numbers, "-", "_" or "."'] = 'O nome das pastas e dos ficheiros devem ser compostos de letras, números, "-", "_" ou "."';
$lang['wrong filename'] = 'nome de ficheiro errado';
$lang['Upload'] = 'Enviar';
$lang['user "%s" added'] = 'utilizador "% adicionado" ';
$lang['User status'] = 'Estatuto de utilizador';
$lang['user_status_admin'] = 'Administrador';
$lang['user_status_generic'] = 'Genérico';
$lang['user_status_guest'] = 'Visitante';
$lang['user_status_normal'] = 'Utilizador';
$lang['user_status_webmaster'] = 'Webmaster';
$lang['Virtual album'] = 'Álbum virtual';
$lang['Waiting'] = 'Aguardando';
$lang['default'] = 'padrão';
$lang['Toggle \'default group\' property'] = 'Ligar/Desligar \'grupo padrão\' propriedade';
$lang['Advanced features'] = 'Características principais';
$lang['Specials'] = 'Ferramentas';
$lang['Overall'] = 'Sempre';
$lang['Year'] = 'Ano';
$lang['Month'] = 'Mês';
$lang['Day'] = 'Dia';
$lang['Pages seen'] = 'Páginas vistas';
$lang['Time'] = 'Tempo';
$lang['IP'] = 'IP';
$lang['Element'] = 'Elemento';
$lang['Section'] = 'Secção';
$lang['Tags'] = 'Etiquetas';
$lang['Save page visits by guests'] = 'Salvar as visitas de página pelos visitantes';
$lang['Save page visits by users'] = 'Salvar as visitas de página pelos utilizadores';
$lang['Save page visits by administrators'] = 'Salvar as visitas de página pelos administradores';
$lang['An information email was sent to group "%s"'] = 'Um email informativo foi enviado para o grupo "%s';
$lang['Send an information email to group members'] = 'Enviar um email informativo aos membros do grupo';
$lang['Group'] = 'Grupo';
$lang['[%s] Visit album %s'] = '[%s] Venha visitar o álbum %s';
$lang['Hello,'] = 'Olá,';
$lang['See you soon.'] = 'Até breve.';
$lang['Discover album:'] = 'Venha descobrir o álbum:';
$lang['Mail content'] = 'Conteúdo do email';
$lang['none'] = 'nenhum';
$lang['high'] = 'alto';
$lang['other'] = 'outro';
$lang['Element type'] = 'Tipo de elemento';
$lang['Image id'] = 'ID da foto';
$lang['Summary'] = 'Sumário';
$lang['%d line filtered'] = '%d linha filtrada';
$lang['%d lines filtered'] = '%d linhas filtradas';
$lang['%d guest'] = '%d visitante';
$lang['%d guests'] = '%d visitantes';
$lang['Hour'] = 'Hora';
$lang['guest'] = 'visitante';
$lang['default values'] = 'valores padrão';
$lang['High filesize'] = 'Tamanho de ficheiro grande';
// --------- Starting below: New or revised $lang ---- from version 1.7.1
$lang['Guest cannot be deleted'] = 'Visitante não pode ser apagado';
$lang['Default user cannot be deleted'] = 'Utilizador padrão não pode ser apagado';
$lang['Purge history detail'] = 'Limpar detalhes do histórico';
$lang['Purge history summary'] = 'Limpar sumário do histórico';
$lang['Check integrity'] = 'Verificar integridade';
$lang['Anomaly'] = 'Anomalia';
$lang['Correction'] = 'Correcção';
$lang['Automatic correction'] = 'Correcção automática';
$lang['Impossible automatic correction'] = 'Impossível efectuar a correcção automática';
$lang['Correction applied with success'] = 'A correcção foi aplicada com sucesso';
$lang['Correction applied with error'] = 'A correcção foi aplicada com erro(s)';
$lang['%d anomaly has been detected.'] = '%d anomalia foi detectada.';
$lang['%d anomalies have been detected.'] = '%d anomalias foram detectadas.';
$lang['%d anomaly has been corrected.'] = '%d anomalia foi corrigida.';
$lang['%d anomalies have been detected corrected.'] = '%d anomalias foram corrigidas.';
$lang['%d anomaly has not been corrected.'] = '%d anomalia não foi corrigida.';
$lang['%d anomalies have not been corrected.'] = '%d anomalias não foram corrigidas.';
$lang['Go to %s or %s for more informations'] = 'Vá ao %s ou %s para mais informações';
$lang['the forum'] = 'fórum';
$lang['the wiki'] = 'wiki';
$lang['%s value is not correct file because exif are not supported'] = 'o valor %s não está correcto porque exif não é suportado';
$lang['%s must be to set to false in your local/config/config.inc.php file'] = '%s deve ser actualizado para falso no seu ficheiro config_local.inc.php';
$lang['Main "guest" user does not exist'] = 'O utilizador principal "visitante" não existe';
$lang['Main "guest" user status is incorrect'] = 'O Estatuto de utilizador do "visitante" principal está incorreto';
$lang['Default user does not exist'] = 'utilizador padrão não existe';
$lang['Main "webmaster" user does not exist'] = 'O utilizador principal "webmaster" não existe';
$lang['Main "webmaster" user status is incorrect'] = 'O estatuto do utilizador principal "webmaster" está incorreto';
$lang['User "%s" created with "%s" like password'] = 'O utilizador "%s" foi criado com "%s" como palavra-passe';
$lang['Status of user "%s" updated'] = 'Estatuto do utilizador "%s" foi atualizado';
$lang['add new photos to caddie'] = 'adicionar novos itens ao carrinho';
// --------- Starting below: New or revised $lang ---- from Butterfly
$lang['No display'] = 'Não exibir';
$lang['Classic display'] = 'Exibição clássica';
$lang['Hoverbox display'] = 'Exibição hoverbox';
$lang['Mail address is obligatory for all users'] = 'Endereço de email é obrigatório para todos os utilizadores';
$lang['Minimum privacy level'] = 'Nível de privacidade mínima';
$lang['Privacy level'] = 'Nível de privacidade';
$lang['Level 0'] = '---';
$lang['Level 1'] = 'Contactos';
$lang['Level 2'] = 'Amigos';
$lang['Level 4'] = 'Família';
$lang['Level 8'] = 'Administradores';
$lang['Reinitialize check integrity'] = 'Reiniciar verificação de integridade';
$lang['Check all'] = 'Marcar tudo';
$lang['Uncheck all'] = 'Desmarcar tudo';
$lang['Check automatic corrections'] = 'Verificar correcções automáticas';
$lang['Apply selected corrections'] = 'Aplicar as correcções seleccionadas';
$lang['Ignore selected anomalies'] = 'Ignorar as anomalias seleccionadas';
$lang['Refresh'] = 'Recarregar a página';
$lang['The anomaly will be ignored until next application version'] = 'A anomalia será ignorada até à próxima versão da aplicação';
$lang['Correction the anomaly will cancel the fact that it\'s ignored'] = 'A correcção da anomalia irá cancelar o facto de estar ignorada';
$lang['%d anomaly has been ignored.'] = '%d anomalia foi ignorada.';
$lang['%d anomalies have been ignored.'] = '%d anomalias foram ignoradas.';
$lang['Plugins which need upgrade'] = 'Plugins que necessitam atualização (upgrade)';
$lang['Plugin list'] = 'Lista de plugins';
$lang['Check for updates'] = 'Procurar atualizações';
$lang['Other plugins'] = 'Outros plugins';
$lang['Last revisions'] = 'Últimas revisões';
$lang['Delete'] = 'Apagar';
$lang['Are you sure you want to delete this plugin?'] = 'Você tem certeza de que você quer apagar este plugin?';
$lang['Are you sure you want to install this plugin?'] = 'Você tem certeza de que você quer instalar este plugin?';
$lang['Are you sure to install this upgrade? You must verify if this version does not need uninstallation.'] = 'Você tem certeza de que você quer instalar esta atualização? Você deve verificar se esta versão não necessita uma desinstalação.';
$lang['%s has been successfully upgraded.'] = '%s foi atualizada com sucesso.';
$lang['Plugin has been successfully copied'] = 'Plugin foi copiado com sucesso';
$lang['You might go to plugin list to install and activate it.'] = 'Você deve ir à lista de plugins para instalar e ativá-lo.';
$lang['Can\'t create temporary file.'] = 'Não é possível criar ficheiro temporário.';
$lang['Can\'t download archive.'] = 'Não é possível descarregar ficheiro.';
$lang['Can\'t read or extract archive.'] = 'Não é possível ler ou extrair ficheiro.';
$lang['An error occured during extraction (%s).'] = 'Houve um erro durante a extração (%s).';
$lang['Please check "plugins" folder and sub-folders permissions (CHMOD).'] = 'Por favor, verifique as permissões das pastas e subpastas de plugins (CHMOD).';
$lang['Can\'t connect to server.'] = 'Não foi possível a conexão com o servidor.';
$lang['Purge compiled templates'] = 'Limpar os modelos compilados';
$lang['ACCESS_0'] = 'Acesso livre';
$lang['ACCESS_1'] = 'Acesso a todos';
$lang['ACCESS_2'] = 'Acesso a subscritores';
$lang['ACCESS_3'] = 'Acesso a administradores';
$lang['ACCESS_4'] = 'Acesso a webmasters';
$lang['ACCESS_5'] = 'Nenhum acesso';
$lang['Support'] = 'Suporte';
$lang['Documentation'] = 'Documentação';
$lang['A new version of Piwigo is available.'] = 'Uma nova versão de Piwigo está disponível.';
$lang['Piwigo Administration'] = 'Administração Piwigo';
$lang['Piwigo version'] = 'Versão Piwigo';
$lang['You are running the latest version of Piwigo.'] = 'Você está usando a última versão de Piwigo.';
$lang['The version of %s [%s] installed is not compatible with the version required [%s]'] = 'A versão instalada de %s [%s] não é compatível com a versão requerida [%s]';
$lang['You need to upgrade your system to take full advantage of the application else the application will not work correctly, or not at all'] = 'Você precisa atualizar seu sistema para aproveitar ao máximo a aplicação, do contrário, a aplicação não funcionará completa ou corretamente.';
$lang['Deleted on'] = 'Apagada em';
$lang['Last hit'] = 'Último acesso (Last hit)';
$lang['GD library is missing'] = 'está faltanto a GD library';
$lang['Templates'] = 'Modelos (Templates)';
$lang['Extend for templates'] = 'Extensões para modelos (templates)';
$lang['Replacement of original templates by customized templates from template-extension subfolder'] = 'Substituição dos modelos originais pelos modelos customizados do subdiretório template-extension';
$lang['Replacers (customized templates)'] = 'Substitutos (modelos customizados)';
$lang['Original templates'] = 'Modelos(templates) originais';
$lang['Optional URL keyword'] = 'palavra chave URL opcional';
$lang['Templates configuration has been recorded.'] = 'A configuração dos modelos (templates) foram gravadas.';
$lang['All optimizations have been successfully completed.'] = 'Todas as otimizações foram finalizadas com sucesso.';
$lang['Optimizations have been completed with some errors.'] = 'As otimizações foram finalizadas com alguns erros.';
$lang['Modify information'] = 'Modificar informação';
$lang['edit album'] = 'editar informações da álbum';
$lang['nothing'] = 'nada';
$lang['overrides existing values with empty ones'] = 'sobrepor os valores existentes com valores vazios';
$lang['manage photo ranks'] = 'gerenciar posições (image ranks)';
$lang['Manage photo ranks'] = 'Gerenciar posições (image ranks)';
$lang['Edit ranks'] = 'Editar posições (ranks)';
$lang['No photo in this album'] = 'Nenhum elemento nesta álbum';
$lang['Images manual order was saved'] = 'A ordem manual das fotos foi salva';
$lang['ranks'] = 'posições (ranks)';
$lang['Drag to re-order'] = 'Arraste para reordenar';
$lang['Quick Local Synchronization'] = 'Sincronização<br>Local Rápida';
$lang['No photo can be deleted'] = 'Nenhuma foto pode ser apagada';
$lang['Delete selected photos'] = 'Apagar as fotos selecionadas';
$lang['%d photo was deleted'] = '%d foto foi apagada';
$lang['%d photos were deleted'] = '%d fotos foram apagadas';
$lang['Downloads'] = 'Downloads';
$lang['Released on'] = 'Lançado em';
$lang['Number of downloads'] = 'Número de downloads';
$lang['Piwigo Announcements Newsletter'] = 'Boletim (newsletter) sobre anúncios do Piwigo';
$lang['Keep in touch with Piwigo project, subscribe to Piwigo Announcement Newsletter. You will receive emails when a new release is available (sometimes including a security bug fix, it\'s important to know and upgrade) and when major events happen to the project. Only a few emails a year.'] = 'Fique atualizado com o projeto Piwigo, assine o boletim (newsletter) dos anúncios do Piwigo. Você receberá emails quando uma nova versão for disponibilizada (às vezes incluindo a correção de um bug, é importante estar por dentro para atualizar) e quando eventos importantes acontecerem no projeto. Apenas uns poucos emails ao longo do ano.';
$lang['Subscribe %s'] = 'Assinar %s';
$lang['Subscribe %s to Piwigo Announcements Newsletter'] = 'Fazer %s assinar o boletim (newsletter) sobre anúncios do Piwigo';
$lang['Purge search history'] = 'Limpar o histórico da pesquisa';
$lang['Hide'] = 'Esconder';
$lang['Miscellaneous'] = 'Outras informações';
$lang['Virtual Links'] = 'Links virtuais';
$lang['Menu Management'] = 'Menú';
$lang['%d of %d photos selected'] = '%d de %d fotos seleccionadas';
$lang['%d photos uploaded'] = '%d fotos enviadas';
$lang['+ Add an upload box'] = '+ Adicionar uma caixa de envio';
$lang['Action'] = 'Acção';
$lang['Activate field "%s"'] = 'Activar campo "%s"';
$lang['Activate icon "%s"'] = 'Activar ícone "%s"';
$lang['Activate Navigation Bar'] = 'Activar Barra de Navegação';
$lang['Activate Navigation Thumbnails'] = 'Activar Navegação por Miniaturas';
$lang['Active Languages'] = 'Activar Linguagens';
$lang['Active Plugins'] = 'Activar Plugins';
$lang['Active Themes'] = 'Activar Temas';
$lang['Add a filter'] = 'Adicionar um filtro';
$lang['Add another set of photos'] = 'Adicionar outro conjunto de fotos';
$lang['Add New Language'] = 'Adicionar Nova Linguagem';
$lang['Add New Theme'] = 'Adicionar Novo Tema';
$lang['Add Photos'] = 'Adicionar Fotos';
$lang['Add write access to the "%s" directory'] = 'Adicionar permissões de escrita à pasta "%s"';
$lang['Administration Home'] = 'Painel Administrativo';
$lang['Album "%s" has been added'] = 'Álbum "%s" foi adicionado';
$lang['Album "%s" now contains %d photos'] = 'Álbum "%s" agora contém %d fotos';
$lang['Album photos associated to the following albums: %s'] = 'Fotos de Álbum associadas aos seguintes álbums: %s';
$lang['Album name'] = 'Nome do Álbum';
$lang['Albums automatically sorted'] = 'Álbums sortidos automaticamente';
$lang['All %d photos are selected'] = 'Todas as %d fotos estão seleccionadas';
$lang['Allow rating'] = 'Permitir Votação';
$lang['Allow user customization'] = 'Permitir Personalização aos Utilizadores';
$lang['Allow users to delete their own comments'] = 'Permitir aos utilizadores apagar os seus comentários';
$lang['Allow users to edit their own comments'] = 'Permitir aos utilizadores editar os seus comentários';
$lang['Apply action'] = 'Aplicar Acção';
$lang['automatic order'] = 'ordem automática';
$lang['Batch Manager'] = 'Gestor de Envio em Massa';
$lang['Bound Theme'] = 'Ligar Tema';
$lang['By %s'] = 'Por %s';
$lang['By rank'] = 'Por classificação';
$lang['Cannot delete the old permalink !'] = 'O permalink antigo não pode ser apagado!';
$lang['Change Admin Colors'] = 'Mudar Cor';
$lang['Choose an action'] = 'Escolha uma acçaõ';
$lang['create a new album'] = 'criar um álbum novo';
$lang['Create the "%s" directory at the root of your Piwigo installation'] = 'Crie a pasta "%s" na raiz da sua instalação Piwigo';
$lang['Delete orphan tags'] = 'Apagar Etiquetas orfãs';
$lang['delete photo'] = 'apagar foto';
$lang['Delete this language'] = 'Apagar esta Linguagem';
$lang['Delete this theme'] = 'Apagar este Tema';
$lang['Directory does not exist'] = 'A pasta não existe';
$lang['Download'] = 'Download';
$lang['Download,'] = 'Download,';
$lang['Drop into album'] = 'Enviar para o álbum';
$lang['duplicates'] = 'duplicados';
$lang['Email administrators when a comment is deleted'] = 'Enviar um Email aos administradores quando um comentário for apagado';
$lang['Email administrators when a comment is modified'] = 'Enviar um Email aos administradores quando um comentário for modificado';
$lang['Error on file "%s" : %s'] = 'Erro no ficheiro "%s" : %s';
$lang['Everybody'] = 'Todos';
$lang['Exif extension not available, admin should disable exif use'] = 'Extensão Exif indisponível, o administrador deve descativar o uso de Exif';
$lang['existing album'] = 'álbum existente';
$lang['Failed to write file to disk'] = 'Falha ao escrever no disco';
$lang['File upload stopped by extension'] = 'Envio de ficheiro parado pela extensão';
$lang['Forbid this language to users'] = 'Proibir esta linguagem aos utilizadores';
$lang['Forbid this theme to users'] = 'Proibir este tema aos utilizadores';
$lang['FTP + Synchronization'] = 'FTP + Sincronização';
$lang['Get Support on Piwigo Forum'] = 'Peça ajuda no fórum Piwigo';
$lang['Give write access (chmod 777) to "%s" directory at the root of your Piwigo installation'] = 'Dê permissões de escrita (chmod 777) à pasta "%s" situada na raiz da sua intalação Piwigo';
$lang['Guest Settings'] = 'Definições de Visitante';
$lang['Help Me'] = 'Ajuda';
$lang['Hit'] = 'Visita';
$lang['Image Quality'] = 'Qualidade da Foto';
$lang['Impossible to activate this theme, the parent theme is missing: %s'] = 'Impossível activar este tema, o tema pai não existe: %s';
$lang['Impossible to deactivate this language, first set another language as default.'] = 'Impossível activar esta linguagem, primeiro escolha outra linguagem por defeito.';
$lang['Impossible to deactivate this language, you need at least one language.'] = 'Impossível desactivar esta linguagem, precisa de ter uma linguagem activa.';
$lang['Impossible to deactivate this theme, you need at least one theme.'] = 'Impossível desactivar este tema, precisa de ter um tema activa.';
$lang['Impossible to delete this theme. Other themes depends on it: %s'] = 'Impossível apagar este tema, outros temas dependem dele: %s';
$lang['In your php.ini file, the upload_max_filesize (%sB) is bigger than post_max_size (%sB), you should change this setting'] = 'No seu php.ini o upload_max_filesize (%sB) é maior que o post_max_size (%sB). Deverá mudar esta definição.';
$lang['Inactive Languages'] = 'Linguagens Inactivas';
$lang['Inactive Plugins'] = 'Plugins Inactivos';
$lang['Inactive Themes'] = 'Temas Inactivos';
$lang['include child albums'] = 'incluír álbums filho';
$lang['Install on your computer,'] = 'Instalar no seu computador,';
$lang['Installed Languages'] = 'Linguagens Instaladas';
$lang['Installed Themes'] = 'Temas Instalados';
$lang['Instructions to use Piwigo'] = 'Instruções para usar Piwigo';
$lang['Invert'] = 'Inverter';
$lang['Keep high definition'] = 'Manter Alta Definição';
$lang['Language has been successfully installed'] = 'Linguagem instalada com sucesso';
$lang['Languages'] = 'Linguagens';
$lang['last import'] = 'última importação';
$lang['Main Page'] = 'Página Principal';
$lang['Make this language available to users'] = 'Permitir aos utilizadores usar esta linguagem';
$lang['Make this theme available to users'] = 'Permitir aos utilizadores usar este tema';
$lang['Manage this set of %d photos'] = 'Gerir este conjunto de %d fotos';
$lang['Manual order'] = 'Ordem Manual';
$lang['manual order'] = 'ordem manual';
$lang['Maximum Height'] = 'Altura máxima';
$lang['Maximum Width'] = 'Largura máxima';
$lang['Missing a temporary folder'] = 'Falta uma pasta temporária';
$lang['Missing Plugins'] = 'Plugins em Falta';
$lang['No file was uploaded'] = 'Nenhum ficheiro foi enviado';
$lang['No photo in the current set.'] = 'Nenhuma foto no conjunto actual.';
$lang['No photo selected, %d photos in current set'] = 'Nenhuma foto seleccionada, %d fotos no conjunto actual';
$lang['No photo selected, no action possible.'] = 'Nenhuma foto seleccionada, Impossível realizar acção.';
$lang['None'] = 'Nenhuma';
$lang['on the %d selected photos'] = 'nas %d fotos seleccionadas';
$lang['Operation in progress'] = 'Operação em progresso.';
$lang['Order of menubar items has been updated successfully.'] = 'A ordem dos items do menú foi actualizada com sucesso.';
$lang['Orphan tags deleted'] = 'Etiquetas orfãs removidas';
$lang['Page end'] = 'Fim de Página';
$lang['Password confirmation error.'] = 'Erro na confirmação da Palavra Passe.';
$lang['Password confirmation is missing. Please confirm the chosen password.'] = 'Confirmação da Palavra Passe em falta. Por favor confirme a Palavra Passe escolhida.';
$lang['Password is missing. Please enter the password.'] = 'Palavra Passe em falta. Por favor escreva a Palavra Passe.';
$lang['Pending Comments'] = 'Comentários Pendentes';
$lang['Photo Page'] = 'Página de Foto';
$lang['Photo Properties'] = 'Propriedades da Foto';
$lang['Photos'] = 'Fotos';
$lang['Piwigo Uploader'] = 'Uploader Piwigo';
$lang['pixels'] = 'pixeis';
$lang['Please wait...'] = 'Aguarde por favor...';
$lang['pLoader stands for <em>Piwigo Uploader</em>. From your computer, pLoader prepares your photos and transfer them to your Piwigo photo gallery.'] = 'pLoader significa <em>Piwigo Uploader</em>. Directamente do seu computador, pLoader prepara as suas fotos e transfere-as para a sua galeria de fotos Piwigo.';
$lang['predefined filter'] = 'filtro predefinido';
$lang['Privacy level set to "%s"'] = 'Nível de privacidade definido para "%s"';
$lang['Read Piwigo Documentation'] = 'Ler Documentação Piwigo';
$lang['Refresh photo set'] = 'Recarregar conjunto de fotos';
$lang['Remove all filters'] = 'Remover todos os filtros';
$lang['remove author'] = 'remover autor';
$lang['remove creation date'] = 'remover data de criação';
$lang['remove this filter'] = 'remover este filtro';
$lang['remove title'] = 'remover título';
$lang['Resize'] = 'Redimensionar';
$lang['Save Settings'] = 'Salvar Definições';
$lang['Select at least one comment'] = 'Seleccione pelo menos um comentário';
$lang['Select files'] = 'Seleccionar ficheiros';
$lang['Select:'] = 'Seleccionar:';
$lang['Selection'] = 'Selecção';
$lang['Set as default language for unregistered and new users'] = 'Definir como Linguagem por defeito para utilizadores não registados e novos utilizadores';
$lang['Set as default theme for unregistered and new users'] = 'Definir como Tema por defeito para utilizadores não registados e novos utilizadores';
$lang['Set author'] = 'Definir autor';
$lang['Set creation date'] = 'Definir data de criação';
$lang['Set title'] = 'Definir título';
$lang['Settings'] = 'Definições';
$lang['Start pLoader and add your photos.'] = 'Iniciar pLoader e adicionar as suas fotos.';
$lang['Switch to clear or dark colors for administration'] = 'Mudar esquema de cores, claro ou escuro, para a administração';
$lang['The following tag was deleted'] = 'A Etiqueta seguinte foi removida';
$lang['The high definition image quality must be a number between %d and %d'] = 'A qualidade da Foto de Alta Definição deve ser um número entre %d e %d';
$lang['The high definition maximum height must be a number between %d and %d'] = 'A Altura máxima para a Foto de Alta Definição deve ser um número entre %d e %d';
$lang['The high definition maximum width must be a number between %d and %d'] = 'A Largura máxima para a Foto de Alta Definição deve ser um número entre %d e %d';
$lang['The thumbnail image quality must be a number between %d and %d'] = 'A qualidade de foto da Miniatura deve ser um número entre %d e %d';
$lang['The thumbnail maximum height must be a number between %d and %d'] = 'A Altura máxima para a Miniatura deve ser um número entre %d e %d';
$lang['The thumbnail maximum width must be a number between %d and %d'] = 'A Largura máxima para a Miniatura deve ser um número entre %d e %d';
$lang['The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form'] = 'O ficheiro enviado excede a directiva MAX_FILE_SIZE especificada no formulário HTML';
$lang['The uploaded file exceeds the upload_max_filesize directive in php.ini: %sB'] = 'O ficheiro enviado excede a directiva upload_max_filesize definida no ficheiro php.ini: %sB';
$lang['The uploaded file was only partially uploaded'] = 'O ficheiro apenas foi enviado parcialmente';
$lang['The uploaded files exceed the post_max_size directive in php.ini: %sB'] = 'Os ficheiros enviados excedem a directiva post_max_sizedefinida no ficheiro php.ini: %sB';
$lang['The websize image quality must be a number between %d and %d'] = 'A qualidade de foto para a Web deve ser um número entre %d e %d';
$lang['The websize maximum height must be a number between %d and %d'] = 'A Altura máxima para a Foto Web deve ser um número entre %d e %d';
$lang['The websize maximum width must be a number between %d and %d'] = 'A Largura máxima para a Foto Web deve ser um número entre %d e %d';
$lang['The whole page'] = 'Página Completa';
$lang['The whole set'] = 'Conjunto Completo';
$lang['Theme has been successfully installed'] = 'O Tema foi instalado com sucesso';
$lang['Themes'] = 'Temas';
$lang['There is no other language available.'] = 'Não existem mais linguagens disponíveis.';
$lang['There is no other plugin available.'] = 'Não existem mais plugins disponíveis.';
$lang['There is no other theme available.'] = 'Não existem mais temas disponíveis.';
$lang['This theme was not designed to be directly activated'] = 'Este tema não foi desenhado para ser activado directamente';
$lang['Tools'] = 'Ferramentas';
$lang['Type here the author name'] = 'Escreva aqui o nome do autor';
$lang['Type here the title'] = 'Escreva aqui o título';
$lang['Uninstalled Plugins'] = 'Plugins Não Instalados';
$lang['Unknown upload error'] = 'Erro de Envio desconhecido';
$lang['unknown'] = 'desconhecido';
$lang['Upload Photos'] = 'Enviar Fotos';
$lang['Uploaded Photos'] = 'Fotos Enviadas';
$lang['Visit Gallery'] = 'Visitar a galeria';
$lang['Visit Piwigo project website'] = 'Visitar o sítio do projecto Piwigo';
$lang['Visit plugin site'] = 'Visitar o sítio do plugin';
$lang['Web size photo'] = 'Foto Web';
$lang['Webmaster status is required.'] = 'Estatuto de Webmaster requerido.';
$lang['Week starts on'] = 'A semana começa em';
$lang['Who can see these photos?'] = 'Quem pode ver estas fotos?';
$lang['Who can see this photo?'] = 'Quem pode ver esta foto?';
$lang['with no album'] = 'sem álbum';
$lang['with no tag'] = 'sem etiquetas';
$lang['with no virtual album'] = 'sem álbum virtual';
$lang['You have %d orphan tags: %s.'] = 'Tem %d etiquetas orfãs: %s.';
$lang['Your configuration settings are saved'] = 'A sua configuração foi guardada';
$lang['Remove from caddie'] = 'Remover do carrinho';
$lang['Themes which need upgrade'] = 'Temas que precisam ser actualizados';
$lang['Languages which need upgrade'] = 'Idiomas que precisam ser actualizados';
$lang['All themes are up to date.'] = 'Todos os Temas est&atilde;o actualizados.';
$lang['All plugins are up to date.'] = 'Todas as extens&otilde;es est&atilde;o actualizadas.';
$lang['All languages are up to date.'] = 'Todos os Idiomas est&atilde;o actualizados.';
$lang['Visit theme site'] = 'Visitar s&iacute;tio do Tema';
$lang['Visit language site'] = 'Visitar  s&iacute;tio do Idioma';
$lang['New Version'] = 'Nova Vers&atilde;o';
$lang['Obsolete Plugins'] = 'Extensões Obsoletas';
$lang['WARNING! This plugin does not seem to be compatible with this version of Piwigo.'] = 'ATENÇÃO! Esta extensão não parece ser compatível com esta versão Piwigo.';
$lang['Do you want to activate anyway?'] = 'Deseja mesmo activar a extensão?';
$lang['THIS PLUGIN IS NOW PART OF PIWIGO CORE! DELETE IT NOW.'] = 'ESTA EXTENSÃO AGORA É PARTE DO NÚCLEO DE PIWIGO! DESINSTALE-A IMEDIATAMENTE!';
$lang['ERROR: THIS PLUGIN IS MISSING BUT IT IS INSTALLED! UNINSTALL IT NOW.'] = 'ERRO: ESTA EXTENSÃO NÃO EXISTE MAS ESTÁ INSTALADA! DESINSTALE-A AGORA.';
$lang['Simulation'] = 'Simulação';
$lang['new'] = 'novo';
$lang['No results'] = 'Sem resultados';
$lang['Searching...'] = 'Procurando...';
$lang['Type in a search term'] = 'Escreva um termo de busca';
$lang['Learn more'] = 'Saber mais';
$lang['Rate'] = 'Classificação';
$lang['Average rate'] = 'Nota média';
$lang['Activate icon "new" next to albums and pictures'] = 'Mostrar o icon "novo" ao lado dos Álbums e das fotos';
$lang['Add a criteria'] = 'Adicionar um critério';
$lang['Deactivate all'] = 'Desactivar tudo';
$lang['Default photos order'] = 'Ordem padrão das fotos';
$lang['Restore'] = 'Restaurar';
$lang['Restore default configuration. You will lose your plugin settings!'] = 'Restaurar a configuração padrão ? Perderá as configurações pesoiais !';
$lang['Show menubar'] = 'Mostrar o menú';
$lang['You can\'t define a default photo order because you have a custom setting in your local configuration.'] = 'Não pode definir uma ordem padrão para as fotos porque tem uma definição na sua configuração local.';																																					
$lang['You have specified <i>$conf[\'order_by\']</i> in your local configuration file, this parameter in deprecated, please remove it or rename it into <i>$conf[\'order_by_custom\']</i> !'] = 'Especificou <i>$conf[\'order_by\']</i> no seu ficheiro de configuração, este pâremetro esta obsoleto, apaguar ou renomear em <i>$conf[\'order_by_custom\']</i> !';
$lang['display'] = 'Mostrar';
$lang['An error has occured during upgrade.'] = 'Ocorreu um erro durante a actualização automática.';
$lang['An error has occured during extract. Please check files permissions of your piwigo installation.<br><a href="%s">Click here to show log error</a>.'] = 'Ocorreu um erro durante a extração dos ficheiros. Por favior verifique as permissões de escrita da sua instalação Piwigo.<br><a href="%s">Clique aqui para mostrar o relatório de erros</a>.';
$lang['Piwigo cannot retrieve upgrade file from server'] = 'Piwigo não consegue recuperar o ficheiro de actualização do servidor remoto.';
$lang['Update in progress... Please wait.'] = 'Actualização em curso... Aguarde, por favor.';
$lang['Update to Piwigo %s'] = 'Actualizar para Piwigo %s';
$lang['Two updates are available'] = 'Duas actualizações disponíveis';
$lang['This is a minor update, with only bug corrections.'] = 'Esta é uma actualização menor, apenas alguns pequenos erros foram corrigidos.';
$lang['This is a major update, with <a href="%s">new exciting features</a>.'] = 'Esta é uma actualização maior, com <a href="%s">novas funcionalidades excitantes</a>.';
$lang['Some themes and plugins may be not available yet.'] = 'Alguns temas e plugins poderão não estar ainda disponíveis.';
$lang['You can update to Piwigo %s directly, without upgrading to Piwigo %s (recommended).'] = 'Pode actualizar para Piwigo %s directamente, sem actualizar primeiro para Piwigo %s (recomendado).';
$lang['Save Template Directory'] = 'Salvar a pasta de Modelos';
$lang['Dump Database'] = 'Descarregar Base de Dados';
$lang['Include history data (Warning: server memory limit may be exceeded)'] = 'Incluir dados históricos (Aviso: pode exceder o limite de memória do servidor)';
$lang['Unable to write new local directory.'] = 'Impossível criar nova pasta local.';
$lang['Unable to send template directory.'] = 'Impossível enviar pasta de modelos.';
$lang['Unable to dump database.'] = 'Impossível descarregar base de dados.';
$lang['ERROR'] = 'ERRO';
$lang['Update Complete'] = 'Actualização Completa';
$lang['Piwigo Update'] = 'Actualizar Piwigo';
$lang['Extensions Update'] = 'Actualizar Extensões';
$lang['All extensions are up to date.'] = 'Todas as extensões estão actualizadas.';
$lang['Following plugins may not be compatible with the new version of Piwigo:'] = 'As seguintes estensões poderão não ser compatíveis com a nova versão de Piwigo:';
$lang['Following themes may not be compatible with the new version of Piwigo:'] = 'Os seguintes temas poderão não ser compatíveis com a nova versão de Piwigo:';


?>